## **Journal of Sports Sciences**

**[ISSN: 0264-0414 (Print) 1466-447X (Online) Journal homepage: http://www.tandfonline.com/loi/rjsp20](http://www.tandfonline.com/loi/rjsp20)**

# **Movement velocity as a measure of exercise** **intensity in three lower limb exercises**

**Filipe Conceição, Juvenal Fernandes, Martin Lewis, Juan José Gonzaléz-**
**Badillo & Pedro Jimenéz-Reyes**

**To cite this article:** Filipe Conceição, Juvenal Fernandes, Martin Lewis, Juan José GonzalézBadillo & Pedro Jimenéz-Reyes (2015): Movement velocity as a measure of exercise intensity in
[three lower limb exercises, Journal of Sports Sciences, DOI: 10.1080/02640414.2015.1090010](http://www.tandfonline.com/action/showCitFormats?doi=10.1080/02640414.2015.1090010)

**To link to this article:** [http://dx.doi.org/10.1080/02640414.2015.1090010](http://dx.doi.org/10.1080/02640414.2015.1090010)

Published online: 22 Sep 2015.

[Submit your article to this journal](http://www.tandfonline.com/action/authorSubmission?journalCode=rjsp20&page=instructions)

Article views: 55

[View related articles](http://www.tandfonline.com/doi/mlt/10.1080/02640414.2015.1090010)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/02640414.2015.1090010&domain=pdf&date_stamp=2015-09-22)

Full Terms & Conditions of access and use can be found at
[http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20](http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20)

**Download by:** \[University of Otago\] **Date:** 26 September 2015, At: 08:20

JOURNAL OF SPORTS SCIENCES, 2015
<http://dx.doi.org/10.1080/02640414.2015.1090010>

### Movement velocity as a measure of exercise intensity in three lower limb exercises

Filipe Conceição a,b, Juvenal Fernandesa, Martin Lewisc, Juan José Gonzaléz-Badillod and Pedro Jimenéz-Reyese

aFaculdade de Desporto, Universidade do Porto, Porto, Portugal; bLaboratório de Biomecânica, Universidade do Porto, Porto, Portugal; cCollege of
Arts and Science, School of Science & Technology, Nottingham Trent University, Nottingham, UK; \[d\] Facultad del Deporte, Universidad Pablo de
Olavide, Sevilla, Spain; \[e\] Faculty of Physical Sciences and Sport, Catholic University of San Antonio, Murcia, Spain

ABSTRACT
The purpose of this study was to investigate the relationship between movement velocity and relative
load in three lower limbs exercises commonly used to develop strength: leg press, full squat and half
squat. The percentage of one repetition maximum (%1RM) has typically been used as the main
parameter to control resistance training; however, more recent research has proposed movement
velocity as an alternative. Fifteen participants performed a load progression with a range of loads
until they reached their 1RM. Maximum instantaneous velocity (Vmax) and mean propulsive velocity
(MPV) of the knee extension phase of each exercise were assessed. For all exercises, a strong relationship between Vmax and the %1RM was found: leg press (r \[2\] adj \[= 0.96; 95% CI for slope is \[\]\[−\]\[0.0244,\]

−0.0258\], P \< 0.0001), full squat (r \[2\] adj \[= 0.94; 95% CI for slope is \[\]\[−\]\[0.0144,\]\[ −\]\[0.0139\],\]\[ P\]\[ \< 0.0001) and half\]

squat (r \[2\] adj \[= 0.97; 95% CI for slope is \[\]\[−\]\[0.0135,\]\[ −\]\[0.00143\],\]\[ P\]\[ \< 0.0001); for MPV, leg press (\]\[r\]\[2\] adj \[= 0.96;\]

95% CI for slope is \[−0.0169, −0.0175\], P \< 0.0001, full squat (r \[2\] adj \[= 0.95; 95% CI for slope is \[\]\[−\]\[0.0136,\]

−0.0128\], P \< 0.0001) and half squat (r \[2\] adj \[= 0.96; 95% CI for slope is \[\]\[−\]\[0.0116, 0.0124\],\]\[ P\]\[ \< 0.0001). The\]

1RM was attained with a MPV and Vmax of 0.21 ± 0.06 m s \[−\]\[1\] and 0.63 ± 0.15 m s \[−\]\[1\], 0.29 ± 0.05 m s \[−\]\[1\] and
0.89 ± 0.17 m s \[−\]\[1\], 0.33 ± 0.05 m s \[−\]\[1\] and 0.95 ± 0.13 m s \[−\]\[1\] for leg press, full squat and half squat,
respectively. Results indicate that it is possible to determine an exercise-specific %1RM by measuring
movement velocity for that exercise.

ARTICLE HISTORY
Accepted 25 August 2015

KEYWORDS
Resistance training;
movement velocity;
intensity; strength

Introduction

The training variables traditionally manipulated to prescribe
and control resistance training programs are typically repetitions, sets, interval time and intensity (Bird, Tarpenning, &
Marino, 2005; Kraemer & Ratamess, 2004; Pereira & Gomes,
2003). Of these, exercise intensity is widely recognised as the
most important variable in resistance training and is normally
reported as a percentage of the individuals one repetition
maximum, %1RM, the maximum load that can be lifted in a
single lift (Fry, 2004; Kraemer & Ratamess, 2004; Pereira &
Gomes, 2003). In order to report this value, it is therefore
necessary to first establish the 1RM for each participant and

exercise.

There are three methods normally used to determine the
1RM: (i) the direct method, which consists of measuring the
maximum weight that can be lifted in a single lift; this method
is generally applied to athletes and trained individuals, (ii) the
prediction method, which estimates the 1RM from the execution of several submaximal repetitions and uses conversion
factors or regression equations and (iii) methods based on
movement velocity.

Maximal tests to measure force are commonly used to test
an athlete’s muscular strength. Although the measurement of
a single maximal lift is the gold standard method for force
evaluation (Franklin, Whaley, Howley, & Balady, 2000), it may
not represent the true maximum of the participant when the
exercise is performed incorrectly or by inexperienced

CONTACT Filipe Conceição <filipe@fade.up.pt>

© 2015 Taylor & Francis

participants (González-Badillo & Sánchez-Medina, 2010). This
method can be dangerous for young athletes or individuals
not accustomed to weight training since it may induce muscle
soreness or risk of muscular injury (Braith, Graves, Leggett, &
Pollock, 1993). Others claim that this method is time consuming and difficult for elderly and physically inactive participants
(Rontu, Hannula, Leskinen, Linnamo, & Salmi, 2010).

Prediction methods are the most commonly used in health
and fitness training, when a single maximum lift might pose a
health or injury risk (Brzycki, 1993; Mayhew et al., 1995, 2002;
Reynolds, Gordon, & Robergs, 2006). These equations are
derived from the heaviest possible load the participant is
able to lift for a predetermined number of repetitions, a
given load for as many repetitions as it is possible in a predetermined time or inducing fatigue within a specific range of
repetitions (Chapman, Whitehead, & Binkert, 1998). Therefore,
many prediction methods common in strength training practice employ exhaustive efforts. Increasing evidence shows that
training to failure does not necessarily improve muscular
strength gains and may even be counterproductive since it
can induce excessive fatigue, mechanical and metabolic strain
and possibly undesirable transition to slower fibres (Fry, 2004).

Another way to monitoring strength training is based on
movement velocity. Although the relationship between velocity and force was established nearly a century ago (Hill, 1938),
it has not been used as a method to control load intensity in
resisted training. Several authors have stressed the importance

2 F. CONCEIÇÃO ET AL.

of velocity in the prescription and control of resistance training, although until recently it was not possible accurately to
measure velocity in typical strength training exercises. The
vast majority of research linking velocity and strength training
were conducted using isokinetic devices which enable only
non-natural movements and are not a common form of train
ing. However, recent studies have established a relationship
between movement velocity and %1RM for a variety of exercises such as the bench press (González-Badillo & SánchezMedina, 2010; Jidovtseff, Harris, Crielaard, & Cronin, 2011;
Rontu et al., 2010) and squat jump (Randell, Cronin, Keogh,
Gill, & Pedersen, 2011). These authors demonstrated that it
was possible to estimate %1RM from a measurement of movement velocity using a linear regression equation.

It was found for the studies incorporating the bench press
that: (i) accurate predictive equations can be established using
submaximal loads with small differences between estimated

and measured strength (Rontu et al., 2010); (ii) there is no
need to perform a 1RM or test the maximum number of
repetitions to failure; (iii) the %1RM being used could be
determined as soon as the first repetition for any given submaximal load and (iv) training load can be prescribed and
monitored according to movement velocity.

Therefore, there may be a number of advantages to the
resistance training coach and athlete: (i) greater accuracy in
prescription and adaptation of resistance exercises, (ii) the
possibility to accurately determine a %1RM value, (iii) realtime feedback of the %1RM and movement velocity in each
repetition during the training session, (iv) the ability to safely
evaluate participants with little training experience and (v) the
possibility of estimating neuromuscular fatigue during a set
(González-Badillo & Sánchez-Medina, 2010, 2010; Jidovtseff

et al., 2011; Rontu et al., 2010).

At present, these applications are limited to the bench
press on which the research was carried out (Argus, Gill,
Keogh, & Hopkins, 2011; González-Badillo & Sánchez-Medina,
2010; Jidovtseff et al., 2011; Rontu et al., 2010) and squat jump
(Randell et al., 2011). Therefore, the purpose of this study was
to investigate the relationship between movement velocity
and the %1RM for the lower body resistance exercises of leg
press, full squat and half squat.

Methods

Participants

A total of 15 male athletes, jumpers and sprinters from track
and field athletics, took part in this study. All track and field
athletes competed at national and/or international level. The
mean age, body mass and stature of the participants were
21 ± 3.61 years old, 70.1 ± 14.5 kg and 1.78 ± 0.07 m, respectively. The inclusion criteria for this study were defined as: (a)
at least 2 years of experience in resistance training; (b) to be
engaged with resistance exercise on at least two occasions
during the week; (c) familiarity with performing the exercises
used in the experiment and (d) between 18 and 30 years of
age. Exclusion criteria were: (a) previous injuries that might
interfere with the study and (b) taking medications or anabolic
steroids.

All participants freely provided written informed consent to
participate in the study in line with the process approved by the
local ethics committee of the University of Porto (Porto, Portugal)
and in agreement with the Declaration of Helsinki.

Experimental procedures
To analyse the relationship between movement velocity and
the %1RM of the exercises, a cross-sectional study design was
used.

Three exercises were studied: the leg press, full squat and
the half squat, since they are considered fundamental resistance exercises for the lower limbs (Bird et al., 2005; Kraemer
& Ratamess, 2004; Pereira & Gomes, 2003). In the first session,
participants went to the laboratory and the researcher provided
an explanation of the protocol in addition to familiarising them
with the instruments. Participants were instructed on how to
perform the exercises for the purposes of this study, using
medium loads. At least 48 h was provided between familiarisation and the start of the data collection sessions.

Prior to data collection, the participants were informed of
the procedures. All participants were provided 10 min to complete a self-designed warm-up consistent with their normal
training routine. Initially, a heart rate monitor was placed on
the participant to control the running warm-up intensity. Each
participant performed a slow 5-min treadmill run, at 60% of
their maximum heart rate, followed by stretching and joint
mobilisation exercises of the lower body. Finally, they performed five repetitions of the exercise to be assessed, with
light loads – 20 kg for the half and full squat and 60 kg for
the leg press. Participants were instructed to perform the lower
limb knee flexion in a controlled manner until they attained full
knee flexion for the full squat and leg press or 90° for the half
squat. They were then asked to hold this position for approxi
–
mately 3 4 s and then extend the knee explosively as fast as
possible following a command provided by the investigator.
This was to eliminate the contribution of elastic energy that
could come for muscle tendon unit stretching since the interest
is in the concentric action performed during knee extension
and not the effect of the stretch shortening cycle. A modified
Smith machine and inclined leg press machine were used to
ensure linear movements, a requirement of the velocity measuring device. During each trial, participants were encouraged
to perform knee extension with maximum voluntary velocity.

Instrumentation

To perform the warm-up and control intensity a treadmill
AMTI Force sensing tandem treadmill (AMTI, Watertown, MA,
USA) and RS polar RS 100 (Polar Electro, Kempele, Finland)
were used.

Bar velocity was measured using a linear transducer sampling at 1000 Hz (T-Force System, Ergotech, Murcia, Spain)
connected to a 16-bit analogue to digital converter (Biopac
MP100 Systems, Santa Barbara, CA, USA) (Figure 1a,b).

The T-force System was interfaced with a personal computer
to automatically calculate the relevant kinematic and kinetic
parameters for every repetition, providing real-time feedback
and data storage. To standardise the starting joint configurations in each repetition, the knee joint angle was measured
using an electrogoniometer (Penny & Gilles, Biometrics Ltd.,

Figure 1. General set-up protocol for (a) the squat and (b) leg press.

Blackwood Ltd., London UK). The full squat and half squat
exercises were conducted using a Smith machine (Multipower
Fitness Line, Peroga, Spain), while for the leg press a custombuilt 45º leg press machine was used (Figure 1a,b).

Data collection

All participants had at least 48 h of rest from their training
routines prior to the test sessions and reported no fatigue at
the start of each test session. The protocol consisted of three
sessions selected in random order with a minimum interval of

5 days between each session. One session was dedicated to
the leg press and the other session was dedicated to the full
squat or the half squat.

A load progression was conducted for each exercise with
six to eight load increments, starting from 20 kg in the half
squat and full squat exercises (≈20% 1RM) and 60 kg in the leg
press (≈30% 1RM). Similar to bench press studies, increments
in each load were approximately 10% 1RM until reaching a
mean propulsive velocity (MPV) of 0.5 m·s \[−\]\[1\] (Sanchez-Medina,
Perez, & Gonzalez-Badillo, 2010), followed by increments of 5
to 1 kg until 1RM was achieved. For those loads moved at a
MPV up to 1.15 m·s \[−\]\[1\], four repetitions were performed with a
3- to 4-min rest interval; two repetitions for medium loads
(0.5 m·s \[−\]\[1\] ≤ MPV ≤ 1.15 m·s \[−\]\[1\] ), with 5-min rest and one
repetition (MPV \< 0.5 m·s \[−\]\[1\] ) for maximum loads and 6-min
recovery. The right knee angle was measured to ensure consistent knee joint angles for each repetition in the load progression. Knee joint angle was defined as zero degrees when
the leg was extended. The command provided by the
researcher to the participant to initiate the knee extension
for the half squat was given when knee flexion had reached
90º or for the full squat and leg press knee flexion was fixed at
115°, a requirement for the repetition to be accepted for
further analysis.

Participants received real-time velocity feedback and were
provided with verbal encouragement to exert their maximum
effort.

Data analysis
Instantaneous velocity was sampled at 1000 Hz. The velocity
data were calibrated and filtered according to the T-force
software specifications (Sánchez-Medina & González-Badillo,
2011). The propulsive phase was defined as the portion of

JOURNAL OF SPORTS SCIENCES 3

the knee extension during which the measured acceleration
was greater than the acceleration due to gravity, the positive
net acceleration (Figure 2) (Sanchez-Medina et al., 2010). This
parameter refers to the portion of the knee extension when
the applied force is positive in the direction of the movement
and thus does not consider the braking phase where the
acceleration is smaller than that of the gravity. The relative
contributions of the propulsive and braking phases during
knee extension for the half squat are shown in Figure 2.

Displacement was obtained by the integration of the velocity with respect to time, the acceleration by differentiation of
the velocity with respect to time and instantaneous force
calculated as F = m·(a + g) where m is the moving load (kg)
and g is the gravitational acceleration.

Two main parameters were analysed: the MPV and the
maximum velocity (Vmax). A full squat, leg press and half
squat repetition was only selected for further analysis when
the knee joint angle at the start of the limb extension met the
joint angle criteria. To establish the relationship between force
and movement velocity as a measure of intensity, the two best
repetitions were selected at light and medium loads and only
one for maximum load was considered for analysis. The criterion was those repetitions with the fastest MPV (GonzálezBadillo & Sánchez-Medina, 2010).

Statistical procedures
Initially, all the data were entered into a spreadsheet (Excel
Microsoft software Corporation, Seattle, WA, USA). To examine
any difference in the form of the relationship between MPV
and %1RM and Vmax and %1RM data were plotted and fitted
by first-order linear polynomials. The degree of linear correlation between movement velocity and the %1RM was examined using Pearson’s product moment correlation (r), R square
(r \[2\] ) and R \[2\] adjusted (r \[2\] adj \[). The confidence interval (CI) was set\]

at 95%. To test the gradients and intercepts of the regression
equations, they were compared with Z-tests using Graphpad
Prism 5.0.1 for Windows (GraphPad Software, San Diego, CA,
USA). When interactions were not significant, analyses were
completed by testing the intercepts. To avoid performing a
multifactorial Z-test, we used the simple Bonferroni correction.
An alpha level of 0.05 was established for statistical significance level.

4 F. CONCEIÇÃO ET AL.

Figure 2. Curve velocity, acceleration time obtained during half squat with 30% load of 1RM by one of the participants of the sample. Propulsive and breaking
phase are delimited by the point where acceleration intersects the x-axis.

Results

The mean and SD of the best performances obtained were: leg
press, 1RM = 235.2 ± 40.7 kg; full squat, 1RM = 124.2 ± 26.6 kg
and half squat, 1RM = 145.0 ± 46.5 kg. For all exercises, a
strong relationship between Vmax and the %1RM was found:
leg press (r \[2\] adj \[= 0.96; 95% CI for slope is \[\]\[−\]\[0.0244,\]\[ −\]\[0.0258\],\]

P \< 0.0001), full squat (r \[2\] adj \[= 0.94; 95% CI for slope is \[\]\[−\]\[0.0144,\]

−0.0139\], P \< 0.0001) and half squat (r \[2\] adj \[= 0.97; 95% CI for\]

slope is \[−0.0135, −0.00143\], P\< 0.0001), as shown in Figure 3.
Similar results were observed in the MPV and the %1RM
relationship: leg press (r \[2\] adj \[= 0.96; 95% CI for slope is\]

\[−0.0169, −0.0175\], P \< 0.0001), full squat (r \[2\] adj \[= 0.95; 95%\]

CI for slope is \[−0.0136, −0.0128\], P \< 0.0001) and half squat
(r \[2\] adj \[= 0.96; 95% CI for slope is \[\]\[−\]\[0.0116,\]\[ −\]\[0.0124\],\]\[ P\]\[ \< 0.0001),\]

as also shown in Figure 3.

The 1RM was attained with an MPV of 0.21 ± 0.03 m·s \[−\]\[1\]

for the leg press, 0.30 ± 0.04 m·s \[−\]\[1\] for the full squat and
0.33 ± 0.03 m·s \[−\]\[1\] for the half squat. Concerning Vmax, the
1RM was achieved with a propulsive velocity of
0.62 ± 0.13 m·s \[−\]\[1\] for the leg press, 0.91 ± 0.14 m·s \[−\]\[1\] for
the full squat and 1.01 ± 0.07 m·s \[−\]\[1\] for the half squat
(Table 1). The changes in the MPV at each 5% load increment in the leg press, full squat and half squat are shown in
Table 2. Increments are fairly stable throughout the entire
range of relative percentages which allowed a linear relationship to be defined between load intensity and movement velocity.

For all the exercises, the differences between the Vmax and
%1RM gradients and the MPV and %1RM gradients were
statistically significant as presented in Table 3 (leg press:
P \< 0.0001, full squat: P = 0.006, half squat: P \< 0.0001).

After testing the slopes for the same exercise in pairs, we move
on to test all the slopes of all the exercises. We found that the

slopes were statistical different with P \< 0.001 except between
Vmax half squat and Vmax full squat where P = 0.055 (Table 4).

Regression equations can be derived to enable the calculation of the percentage 1RM being lifted based on the MPV of
the movement. These equations are as follows:

(a) Full squat, load = −71.684 × (MPV) + 121.03; r \[2\] adj \[= 0.95;\]

95% CI for slope is \[−69.41, −74,137\], P \< 0.001

(b) Half squat, load = −80.372 × (MPV) + 125.19; r \[2\] adj \[= 0.96;\]

95% CI for slope is \[−77.95, −82,289\], P \< 0.001

(c) Leg press, load = −55.509 × (MPV) + 109.29; r \[2\] adj \[= 0.96;\]

95% CI for slope is \[−53.883, −57.134\], P \< 0.001

Following a comparison of Vmax slopes for full squat and
half squat, we investigated their intercepts, which revealed
they were significantly different (P \< 0.0001). Differences

–
between the maximum velocity load relationship (gradient)
for the full squat and half squat were small. For this reason,
a common equation could be defined for both exercises by
assuming their gradients to have equal magnitude. Therefore
doing so a new common equation for both these exercises has
been established (Figure 4).

Full squat and half squat, load = −68.581 × (Vmax) + 2.512;
r \[2\] \[−\]\[67.156,\]\[ −\]\[70.005\],\]\[ P\]\[ \< 0.001.\]

(a) Full squat, load = −71.684 × (MPV) + 121.03; r \[2\]

(b) Half squat, load = −80.372 × (MPV) + 125.19; r \[2\]

(c) Leg press, load = −55.509 × (MPV) + 109.29; r \[2\]

adj \[= 0.96; 95% CI for slope is \[\]\[−\]\[67.156,\]\[ −\]\[70.005\],\]\[ P\]\[ \< 0.001.\]

Discussion

The results obtained here indicate a strong relationship
between the maximum instantaneous velocity and the %
1RM for three lower body resistance exercises – full squat,
half squat and leg press. These results are in agreement with
previous studies that identified a relationship between the
movement velocity and %1RM for the bench press
(González-Badillo & Sánchez-Medina, 2010; Jidovtseff et al.,

2011; Rontu et al., 2010).

JOURNAL OF SPORTS SCIENCES 5

Figure 3. Measurement of relative load and Vmax (round dots), relative load and MPV (crosses) for the (a) full squat, (b) half squat and (c) leg press.

Table 1. Maximum instantaneous velocity and mean propulsive velocity when
the 1RM is attained during each of the exercises (mean ±SD).

Exercise Maximum velocity (m·s \[−\]\[1\] ) Mean propulsive velocity (m·s \[−\]\[1\] )

Full squat 0.91 ± 0.14 0.30 ± 0.04
Half squat 1.01 ± 0.07 0.33 ± 0.04
Leg press 0.62 ± 0.13 0.21 ± 0.04

Our results reveal that when knee extension for these exer
cises is performed at maximal velocity, the %1RM can be estimated for each repetition with real-time feedback. To measure
the %1RM of repetitions exclusively using maximal knee extension velocity may complement the training process as a form of
athlete monitoring, since maximal velocity lifts have been proposed as an effective resistance training method (Bell, Petersen,
MacLean, Reid, & Quinney, 1992; Bell & Wenger, 1992; Cronin,
McNair, & Marshall, 2002; Garcia-Pallares, Sanchez-Medina,
Perez, Izquierdo-Gabarren, & Izquierdo, 2010; Hasegawa, 2010;
Sánchez-Medina & González-Badillo, 2011). Maximum velocity
lifts have been proposed to: (i) increase motivation (Hasegawa,
2010), (ii) maintain the intended movement velocity to

Table 2. Predicted mean propulsive velocity (m·s \[−\]\[1\] ) for the leg press, squat and
half squat at each intensity (%1RM).

Load (% 1 RM) Leg press Squat Half squat

15 1.66 1.45 1.35

20 1.58 1.38 1.29

25 1.49 1.32 1.23

30 1.4 1.25 1.17

35 1.32 1.18 1.11

40 1.23 1.12 1.05

45 1.15 1.05 0.99

50 1.06 0.99 0.93

55 0.97 0.92 0.87

60 0.89 0.85 0.81

65 0.79 0.79 0.75

70 0.71 0.72 0.69

75 0.63 0.66 0.63

80 0.54 0.59 0.57

85 0.45 0.52 0.51

90 0.37 0.46 0.45

95 0.28 0.39 0.39

100 0.19 0.33 0.33

maximise the intra- and inter-coordination of neuromuscular

units (Garcia-Pallares et al. (2010); Hasegawa, 2010), (iii) be

6 F. CONCEIÇÃO ET AL.

Table 3. Comparison between the slopes of Vmax, to %1RM versus MPV, to %
1RM for full squat, half squat and leg press.

Variable 1 Variable 2 Slope comparison

Vmax – % 1RM of full squat MPV – % 1RM of full squat P = 0.0067
Vmax – % 1RM of half squat MPV – % 1RM of half squat P \< 0.0001
Vmax – % 1RM of leg press MPV – % 1RM of leg press P \< 0.0001

Table 4. Comparison between the slopes of the relationship movement velocity
versus relative load, for the Vmax in the full squat, half squat and leg press for
the MPV in the full squat, half squat and leg press.

Relationship slope Relationship slope Slope comparison

a. Vmax full squat Vmax half squat P = 0.0552
Vmax full squat Vmax leg press P \< 0.0001
Vmax half squat Vmax leg press P \< 0.0001

b. MPV full squat MPV half squat P \< 0.0001
MPV full squat MPV leg press P \< 0.0001
MPV half squat MPV leg press P \< 0.0001

more effective for advanced training than traditional slow velocities performed with moderately high loads (Jones, Hunter,
Fleisig, Escamilla, & Lemak, 1999; Kraemer & Ratamess, 2004),
(iv) increase anaerobic power output (Bell et al., 1992), (v)
promote a change in skeletal muscle size and change in myofibrillar ATPase activity (Bell et al., 1992; Bell & Wenger, 1992) and
(vi) monitor the degree of incurred fatigue (González-Badillo,
Marques, & Sánchez-Medina, 2011; Sánchez-Medina &
González-Badillo, 2011).

The relationship between %1RM and movement velocity
was found to be specific to the resistance exercise. Small
standard deviations (Table 1) were found for the mean propulsive velocities attained at the 1RM, especially when the
MPV is used. These results suggest that MPV may be a more
precise method for predicting the 1RM. When using the full
range of loads, both the MPV and Vmax can be used with
confidence to determine the %1RM for that exercise (Table 2).

A strong movement velocity to %1RM relationship was found
elsewhere for the bench press (González-Badillo & SánchezMedina, 2010; Jidovtseff et al., 2011; Rontu et al., 2010), and the
current research has extended that understanding to the exercises of full squat, half squat and leg press. A common equation
can describe the relationship between Vmax and the %1RM for
the full squat and half squat, and this is most likely to result from

a half squat being a sub-unit of the full squat exercise (Figure 4).
Since the results demonstrated a similar gradient for half squat
and full squat versus %1RM with differences predominantly in
the intercepts, a general equation can be used for both. Both
exercises behave similarly (Figure 4) and their main differences
are in absolute values, i.e. the magnitude of the load. Another
interesting fact is that the leg press presents significant difference with the gradients and intercepts of the full squat and half
squat, despite recruiting similar muscle groups. Potentially, these
differences lie with the hip position which relates to some muscles operating on different parts of their force length relationship. Without multi-joint kinematic data, it is only possible to
speculate.

The route mean square difference between measured and
calculated %1RM from MPV using regression equations was
5.8%, 7.3% and 7.7% for the leg press, full squat and half
squat, respectively. Since the equations for defining full and
half squats were so similar, it was of interest to investigate
how their respective equations might affect calculated %1RM
when using the other movement’s equation. When the equation for calculating the percentage of 1RM from MPV of the
full squat was employed to calculate the percentage of 1RM
for the half squat, there was a route mean square difference of
8.5% as compared to a route mean square difference of 7.7%
obtained using its own equation. When employing the equation for calculating the percentage of 1RM from MPV of the
half squat to calculate the percentage of 1RM for the full
squat, there was a route mean square difference of 8.4% as
compared to the rout mean square difference 7.3% when
using its own equation.

A strong relationship was found between MPV and load for
the leg press, full squat and half squat which can be seen in
Figure 3, with r \[2\] adj \[values of 0.96, 0.95 and 0.96, respectively.\]

Previous investigations conducted for the bench press exercise also revealed a close relationship (r \[2\] = 0.98) between
relative load (%1RM) and movement velocity (GonzálezBadillo & Sánchez-Medina, 2010). This strong relationship can
be used to predict or adjust the 1RM value during a training
session simply by measuring the execution velocity. Note that
due to fatigue and other conditions, the 1RM values fluctuate
between training sessions. It was interesting to verify that the

Figure 4. Common predictive equation for relative load and Vmax for combined squat and half squat data.

propulsive velocity difference between 5% load increments
from 30% to 100% of 1RM for leg press, squat and half squat
were 0.087, 0.066 and 0.06 m·s \[−\]\[1\], respectively (Table 2). As
noted by González-Badillo and Sánchez-Medina (2010), when
a participant increases their MPV by an increment as shown
above, then this might be used to establish a 5% increase in
strength. These are multi-joint exercises and involve some of
the largest and most powerful muscles of the body, which
may explain why the velocities measured in this study were
larger than those found in the literature for the bench press.

Some questions might be raised regarding the value in
being able to approximate load from movement velocity as
a tool to develop strength: Which is best – fast or slow lifts? Is
it appropriate to adopt fast lifts over slow lifts to enhance
strength gains?

Most research conducted in the past that attempted to
answer these questions was inconclusive, and this was most
likely the result of methodological inconsistences such as: (i)
not equating volume and loading magnitude between different training interventions (Fielding et al., 2002; Pereira &
Gomes, 2003); (ii) the use of exercise sets performed up to or
close to muscle failure, which tends to equalise the overall
training velocities between fast and slow velocities such that
they are very similar (Cronin, McNair, & Marshall, 2001) and (iii)
the velocities were not rigorously controlled (Ingebrigtsen,
Holtermann, & Roeleveld, 2009).

More recent research by González-Badillo, Rodríguez-Rosell,
Sánchez-Medina, Gorostiaga, and Pareja-Blanco (2014) has
suggested that movement velocity may be considered the
most important factor in resistance training since at a given
magnitude (%1RM), the velocity at which the load is moved
determines the resulting training effect. By comparing 6 weeks
of strength training with loads moved at maximum velocity or
at half of maximum velocity, the strength gains were larger in
the fast group relative to the slower one. Moreover, these
results were obtained without participants exceeding half of
the maximum possible number of repetitions possible per set.
The explanation for the superior strength gain from the faster
lifting techniques has been proposed to be the increased
activation of agonist muscles required to overcome the load
with fast concentric muscle actions (Sakamoto & Sinclair, 2012)
where larger peak forces are attained for each repetition
(Hatfield et al., 2006).

Our results show similar correlations between movement

velocity and %1RM to those found in the literature
(González-Badillo & Sánchez-Medina, 2010; Jidovtseff et al.,
2011; Rontu et al., 2010), and therefore the full squat, half
squat and leg press exercises may benefit from the same
advantages: (i) prediction of 1RM with submaximal loads
available from the first repetition of each training session
(Jidovtseff et al., 2011; Rontu et al., 2010), (ii) calibration of
training load from daily athlete performance level and (iii)
continuous evaluation of resistance training progress
(Jidovtseff et al., 2008).

The present method imposed pauses of 3–4 s between
the eccentric and concentric phases. The purpose of this
design was the elimination of the stretch shorten cycle
effects in the force developed. A pause between the
eccentric and concentric contraction appears to be good

JOURNAL OF SPORTS SCIENCES 7

practice since it leads to the minimisation of the measured
error by reducing the variability in the measurements and
producing more reliable isoinertial assessment. Although it is
not common in training practice and may affect the ecological validity, some compromise is required in order to employ
a method of field-based assessment with high reliability
(Reilly, Morris, & Whyte, 2009).

Last, although movement velocity has a very close relationship to %1RM (Sanchez-Medina et al., 2010) and could be
used as a more valuable parameter in the training control
process than the 1RM, this procedure could present some
potential limitations because it requires adequate experience
from the athlete to avoid underestimating the intensity.
Whilst expensive equipment has been used to acquire the
data for this study, a range of inexpensive video-based analysis systems might be used to recreate a similar method of
calculation in an applied setting with only a limited effect on

measurement error.

Conclusions

Based on the results obtained in this study, it is proposed that
for athletes with competent and consistent lifting techniques,
the MPV should be used to estimate the %1RM in the full

squat, half squat and leg press exercises, using the equations
presented in the results section.

Strength and conditioning practitioners may choose MPV
or Vmax to predict and/or monitor the %1RM without the need
to perform a 1RM test. A range of inexpensive video analysis
software could be used to achieve this.

In conclusion, the results obtained in this study indicate
that the %1RM can be estimated for each repetition during
strength training sessions using real-time feedback. Strength
can be estimated from movement velocity and submaximal
loads and hence avoid the potential increased injury risk from
the standard 1RM protocol.

Acknowledgements

We are very grateful to the athletes of the Escola do Movimento Track and
Field club for their involvement in the study.

Disclosure statement

No potential conflict of interest was reported by the authors.

ORCID

Filipe Conceição [http://orcid.org/0000-0002-1636-2685](http://orcid.org/0000-0002-1636-2685)

References

Argus C. K., Gill N. D., Keogh J. W. L., & Hopkins W. G. (2011). Acute effects

of verbal feedback on upper-body performance in elite athletes.
Journal of Strength and Conditioning Research, 25(12), 3282–3287.
Bell G. J., Petersen S. R., MacLean I., Reid D. C., & Quinney H. A. (1992).

Effect of high velocity resistance training on peak torque, cross sectional area and myofibrillar ATPase activity. The Journal of Sports
Medicine and Physical Fitness, 32, 10–18.

8 F. CONCEIÇÃO ET AL.

Bell G. J., & Wenger H. A. (1992). Physiological adaptations to velocitycontrolled resistance training. Sports Medicine, 13, 234–244.
Bird S. P., Tarpenning K. M., & Marino F. E. (2005). Designing resistance
training programmes to enhance muscular fitness: A review of the
acute programme variables. Sports Medicine, 35, 841–851.
Braith R., Graves J., Leggett S., & Pollock M. (1993). Effect of training on the
relationship between maximal and submaximal strength. Medicine &
Science in Sports & Exercise, 25, 132–138.

—
Brzycki M. (1993). Strength testing predicting a one-rep max from repsto-fatigue. Journal of Physical Education, Recreation & Dance, 64, 88–90.
Chapman P. P., Whitehead J., & Binkert R. (1998). The 225-lb reps-tofatigue test as a submaximal estimate of 1-RM bench press performance in college football players. Journal of Strength Conditioning
Research, 12, 258–261.
Cronin J., McNair P. J., & Marshall R. N. (2001). Velocity specificity, combination training and sport specific tasks. Journal of Science and Medicine
in Sport, 4, 168–178.
Cronin J. B., McNair P. J., & Marshall R. N. (2002). Is velocity-specific
strength training important in improving functional performance?
Journal of Sports Medicine and Physical Fitness, 42, 267–273.
Fielding R. A., LeBrasseur N. K., Cuoco A., Bean J., Mizer K., & Fiatarone
Singh M. A. (2002). High-velocity resistance training increases skeletal
muscle peak power in older women. Journal of the American Geriatrics
Society, 50, 655–662.
Franklin B. A., Whaley M. H., Howley E. T., & Balady G. J. (2000). American
College of Sports Medicine. ACSM’s guidelines for exercise testing and
prescription (6th ed.). Philadelphia: Lippincott Williams & Wilkins.
Fry A. C. (2004). The role of resistance exercise intensity on muscle fibre
adaptations. Sports Medicine, 34, 663–679.
Garcia-Pallares J., Sanchez-Medina L., Perez C. E., Izquierdo-Gabarren M.,
& Izquierdo M. (2010). Physiological effects of tapering and detraining
in world-class kayakers. Medicine and Science Sports and Exercise, 42,

1209–1214.

González-Badillo J. J., Marques M. C., & Sánchez-Medina L. (2011). The
importance of movement velocity as a measure to control resistance
training intensity. Journal of Human Kinetics, 29A, 15–19.
González-Badillo J. J., Rodríguez-Rosell D., Sánchez-Medina L., Gorostiaga E.
M., & Pareja-Blanco F. (2014). Maximal intended velocity training induces
greater gains in bench press performance than deliberately slower halfvelocity training. European Journal of Sport Science, 14(8), 772–781.
González-Badillo J. J., & Sánchez-Medina L. (2010). Movement velocity as a
measure of loading intensity in resistance training. International Journal
of Sports Medicine, 31, 347–352.
Hasegawa H. (2010). A real time feedback and monitoring of speed and
power in resistance training for athletes. In: H. Dusan ed. 7th
International Congress on Strength Training Abstracts. Bratislava, 51–54.
Hatfield D. L., Kraemer W. J., Spiering B. A., Häkkinen K., Volek J. S.,
Shimano T., . . . Maresh C. M. (2006). The impact of velocity of movement on performance factors in resistance exercise. Journal of Strength
Conditioning Research, 20(4), 760–766.
Hill A. V. (1938). The heat of shortening and the dynamics constants of
muscle. Proceedings of Royal Society London Serv. B, 126(843), 136–195.
Ingebrigtsen J., Holtermann A., & Roeleveld K. (2009). Effects of load and
contraction velocity during three-week biceps curls training on

isometric and isokinetic performance. Journal of Strength and
Conditioning Research, 23(6), 1670–1676.
Jidovtseff B., Croisier J., Scimar N., Demoulin C., Maquet D., & Crielaard
J. (2008). The ability of isoinertial assessment to monitor specific
training effects. Journal of Sports Medicine and Physical Fitness, 48,

55–64.

Jidovtseff B., Harris N. K., Crielaard J.-M., & Cronin J. B. (2011). Using the
load-velocity relationship for 1RM prediction. Journal of Strength and
Conditioning Research, 25, 267–270.
Jones K., Hunter G., Fleisig G., Escamilla R., & Lemak L. (1999). The effects
of compensatory acceleration on upper-body strength and power in
collegiate football players. Journal of Strength and Conditioning
Research, 13, 99–105.
Kraemer W. J., & Ratamess N. A. (2004). Fundamentals of resistance training: Progression and exercise prescription. Medicine & Science in Sports
& Exercise, 36, 674–688.
Mayhew J. L., Prinster J. L., Ware J. S., Zimmer D. L., Arabas J. R., & Bemben
M. G. (1995). Muscular endurance repetitions to predict bench press
strength in men of different training levels. Journal of Sports Medicine
and Physical Fitness, 35, 108–113.
Mayhew J. L., Ware J. S., Cannon K., Corbett S., Chapman P. P., Bemben M.
G., . . . Slovak J. P. (2002). Validation of the NFL-225 test for predicting 1RM bench press performance in college football players. Journal of
Sports Medicine and Physical Fitness, 42, 304–308.
Pallarés J. G., Sánchez-Medina L., Pérez C. E., De La Cruz-Sánchez E., &
Mora-Rodriguez R. (2014). Imposing a pause between the eccentric
and concentric phases increases the reliability of isoinertial strength
assessments. Journal of Sports Sciences, 32(12), 1165–1175.
Pereira M. I., & Gomes P. S. (2003). Movement velocity in resistance
training. Sports Medicine, 33, 427–438.
Randell A. D., Cronin J. B., Keogh J. W. L., Gill N. D., & Pedersen M. C. (2011).
Effect of instantaneous performance feedback during 6 weeks of velocity-based resistance training on sport specific performance tests. Journal
of Strength and Conditioning Research, 25(1), 87–93.
Reilly T., Morris T., & Whyte G. (2009). The specificity of training prescription and physiological assessment: A review. Journal of Sports Sciences,
27(6), 575–589.
Reynolds J. M., Gordon T. J., & Robergs R. A. (2006). Prediction of one
repetition maximum strength from multiple repetition maximum testing and anthropometry. Journal Strength and Conditioning Research,
20, 584–592.

Rontu J.-P., Hannula M. I., Leskinen S., Linnamo V., & Salmi J. A. (2010).
One-repetition maximum bench press performance estimated with a
new accelerometer method. Journal of Strength and Conditioning
Research, 24, 2018–2025.
Sakamoto A., & Sinclair P. J. (2012). Muscle activations under varying lifting
speeds and intensities during bench press. European Journal of Applied
Physiology, 112, 1015–1025.
Sánchez-Medina L., & González-Badillo J. J. (2011). Velocity loss as an
indicator of neuromuscular fatigue during resistance training.
Medicine & Science in Sports & Exercise, 43, 1725–1734.
Sanchez-Medina L., Perez C. E., & Gonzalez-Badillo J. J. (2010). Importance
of the propulsive phase in strength assessment. International Journal of
Sports Medicine, 31, 123–129.
